@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-sort-plugin.c 4883 2006-05-15 09:06:37Z pborelli $
+ * $Id: gedit-sort-plugin.c 6498 2008-09-07 13:50:57Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -108,7 +108,7 @@ sort_dialog_response_handler (GtkDialog  *widget,
 
 		case GTK_RESPONSE_HELP:
 			gedit_help_display (GTK_WINDOW (widget),
-					    "gedit.xml",
+					    NULL,
 					    "gedit-sort-plugin");
 			break;
 
@@ -129,20 +129,22 @@ get_sort_dialog (GtkWindow *parent)
 
 	dialog = g_new (SortDialog, 1);
 
-	ret = gedit_utils_get_glade_widgets (GEDIT_GLADEDIR "sort.glade2",
-					     "sort_dialog",
-					     &error_widget,
-					     "sort_dialog", &dialog->dialog,
-					     "reverse_order_checkbutton", &dialog->reverse_order_checkbutton,
-					     "col_num_spinbutton", &dialog->col_num_spinbutton,
-					     "ignore_case_checkbutton", &dialog->ignore_case_checkbutton,
-					     "remove_dups_checkbutton", &dialog->remove_dups_checkbutton,
-					     NULL);
+	ret = gedit_utils_get_ui_objects (GEDIT_UIDIR "sort.ui",
+					  NULL,
+					  &error_widget,
+					  "sort_dialog", &dialog->dialog,
+					  "reverse_order_checkbutton", &dialog->reverse_order_checkbutton,
+					  "col_num_spinbutton", &dialog->col_num_spinbutton,
+					  "ignore_case_checkbutton", &dialog->ignore_case_checkbutton,
+					  "remove_dups_checkbutton", &dialog->remove_dups_checkbutton,
+					  NULL);
 
 	if (!ret)
 	{
-		gedit_warning (parent,
-			       gtk_label_get_label (GTK_LABEL (error_widget)));
+		const gchar *err_message;
+
+		err_message = gtk_label_get_label (GTK_LABEL (error_widget));
+		gedit_warning (parent, "%s", err_message);
 
 		g_free (dialog);
 		gtk_widget_destroy (error_widget);
